import asyncio
import base64
import httpx

from spacedork.reps.base import SearchBase


def format_fofa(item):
    new_item = {
        "url": f'{item[0]}://{item[1]}:{item[2]}',
        "ip": item[1],
        "port": item[2],
    }
    return new_item


class Fofa(SearchBase):
    def __init__(self, token=None, email=None, thread=2, **kwargs):
        super().__init__(**kwargs)
        self.url = 'https://fofa.info'
        self.token = token
        self.email = email
        self.resources = None
        self.plan = None
        self.client = httpx.AsyncClient()
        self.client.headers = {'User-Agent': 'Python spacedork Client 3.0'}
        self.semaphore = asyncio.Semaphore(thread)
        self.total = -1

    async def query(self, dork: str, page: int):
        async with self.semaphore:
            if 0 < self.total < (page - 1) * 20:
                return
            url = f'{self.url}/api/v1/search/all'
            try:
                resp = await self.client.get(url, timeout=60,
                                             params={"qbase64": base64.b64encode(dork.encode()).decode(),
                                                     "page": page, "key": self.token,
                                                     "email": self.email,
                                                     "fields": "protocol,ip,port"})
            except Exception as e:
                print(f"Req Error:{e}")
                return
            if resp and resp.status_code == 200:
                content = resp.json()
                total = content['size']
                self.total = total
                for match in content['results']:
                    item = format_fofa(match)
                    self.echo(item)
            else:
                print(f"req Error:{resp}")

    async def search(self, dork, start_page=1, end_page=1, resource='host') -> (list, int):
        tasks = []
        items = []
        total = 0
        for page in range(start_page, end_page + 1):
            tasks.append(asyncio.create_task(self.query(dork, page)))
        await asyncio.gather(*tasks)
        return items, total


if __name__ == "__main__":
    zoomeye = Fofa("", email="")
    loop = asyncio.get_event_loop()
    loop.run_until_complete(zoomeye.search("weblogic"))



import asyncio
import logging
import time

import httpx

from spacedork.reps.base import SearchBase


def format_zoomeye(item):
    new_item = {}
    if isinstance(item["ip"], list):
        if item["ip"]:
            new_item["ip"] = item["ip"][0]
        else:
            new_item["ip"] = ""
    else:
        new_item["ip"] = item['ip']
    port = str(item['portinfo']['port'])
    if "site" in item and item["site"]:
        new_item["url"] = "http://{}".format(item["site"])
    else:
        if "443" in port:
            new_item["url"] = f"https://{item['ip']}:{port}"
        else:
            new_item["url"] = f"http://{item['ip']}:{port}"
    if "country_name_CN" in item:
        new_item["country"] = item.pop("country_name_CN")
    if "subdivisions_name_CN" in item:
        new_item["city"] = item.pop("subdivisions_name_CN")
    return new_item


class ZoomEye(SearchBase):
    def __init__(self, token,thread=2, **kwargs):
        super().__init__(**kwargs)
        self.url = 'https://api.zoomeye.org'
        self.token = token
        self.resources = None
        self.plan = None
        self.client = httpx.AsyncClient()
        self.client.headers = {'User-Agent': 'Python Zoomeye Client 3.0', 'API-KEY': token}
        self.semaphore = asyncio.Semaphore(thread)
        self.total = -1


    async def query(self, dork: str, page: int, resource='host'):
        async with self.semaphore:
            if 0 < self.total < (page - 1) * 20:
                return
            url = f'{self.url}/{resource}/search'
            try:
                resp = await self.client.get(url, timeout=60, params={"query": dork, "page": page})
            except Exception as e:
                print(f"Req Error:{e}")
                return
            if resp and resp.status_code == 200 and 'matches' in resp.text:
                content = resp.json()
                total = content['total']
                self.total = total
                for match in content['matches']:
                    item = format_zoomeye(match)
                    print(item['url'])
            else:
                print(f"req Error:{resp}")

    async def search(self, dork, start_page=1, end_page=1, resource='host') -> (list, int):
        tasks = []
        items = []
        total = 0
        for page in range(start_page, end_page + 1):
            tasks.append(asyncio.create_task(self.query(dork, page, resource=resource)))
        await asyncio.gather(*tasks)
        return items, total


if __name__ == "__main__":
    zoomeye = ZoomEye("")
    loop = asyncio.get_event_loop()
    loop.run_until_complete(zoomeye.search("weblogic"))



import argparse
import asyncio
import os
import yaml

import reps

home_directory = os.path.expanduser("~")
config_file_path = os.path.join(home_directory, ".config", '', 'config.yaml')


def cmd_parser():
    parser = argparse.ArgumentParser(description='这是一个示例命令行参数解析程序')
    parser.add_argument('--list-module', required=False, help='列举所有模块', action='store_true')
    parser.add_argument('--config', '-c', required=False, help=f'配置文件路径({config_file_path})',
                        default=config_file_path)
    parser.add_argument('--dork', '-q', required=False, help='查询dork关键字')
    parser.add_argument('--module', '-m', required=False, default='zoomeye', help='使用查询模型')
    parser.add_argument('--start-page', '-sp', type=int, default=1, help='要处理的数量')
    parser.add_argument('--end-page', '-ep', type=int, default=1, help='要处理的数量')
    parser.add_argument('--help', '-h', type=int, action='store_true', help='HELP')
    args = parser.parse_args()
    if args.list_module:
        for k, v in reps.repo.items():
            print(k)
        exit()
    elif not args.dork:
        print("请提供dork关键字")
        exit()
    return args


def main():
    args = cmd_parser()
    with open(args.config, "r") as yaml_file:
        try:
            yaml_data = yaml.safe_load(yaml_file)
        except yaml.YAMLError as e:
            print(f"YAML解析错误: {e}")
            return
    plugin = reps.repo.get(args.module)
    plugin_config = yaml_data.get(args.module, {})
    cls = plugin(**plugin_config)
    coroutine = cls.search(args.dork, args.start_page, args.end_page)
    loop = asyncio.get_event_loop()
    loop.run_until_complete(coroutine)


if __name__ == '__main__':
    main()



class SearchBase(object):
    def __init__(self,fields="url",**kwargs):
        self.fields = fields
    async def search(self,**kwargs):
        pass

    def echo(self,item):
        if self.fields=="address":
            print(f"{item['ip']}:{item['port']}")
        else:
            print(item[self.fields])



from setuptools import setup, find_packages
setup(
    name='spacedork',
    version="3.3.0",
    url='',
    description='',
    long_description='',
    keywords='dork search',
    author='',
    author_email='tongchengbin@outlook.com',
    maintainer='',
    platforms=['any'],
    license='',
    zip_safe=False,
    include_package_data=True,
    python_requires='>=3.6',
    packages=find_packages('.'),
    entry_points={
        "console_scripts": [
            "dork = spacedork.cli:main"
        ]
    },
    install_requires=[
        "httpx",
        "PyYAML",

    ],
)
